
DunnetCritic=function(gld,gln,sig){

D0.001=c(31.70911445,39.50204486,44.05741169,47.22292126,49.62479055,51.54744566,53.1428387,54.50127044,55.68062337,56.7201573,57.64769067,58.48363184,59.24338183,59.93883818,60.5793748,61.17250261,61.724328,62.23987885,62.72334167,63.1782372,65.11516556,66.64854524,67.91224282,68.98401679,69.91276957,70.73111913,72.12139827,
         12.95498338,15.37000099,16.79443314,17.79454632,18.55972184,19.17637644,19.69103786,20.13154697,20.51584157,20.8561315,21.16108883,21.4370857,21.68893623,21.9203627,22.13430022,22.33310254,22.51868498,22.69262618,22.85624209,23.01064076,23.67307817,24.20332976,24.64412036,25.02051831,25.34845066,25.63864617,26.13402352,
         8.626643618,9.94461844,10.72354818,11.27303531,11.69532729,12.03697934,12.32307811,12.56866262,12.78344412,12.97404836,13.1451923,13.30034985,13.4421512,13.57263423,13.69340897,13.80576886,13.9107682,14.00927732,14.10202278,14.18961718,14.56622688,14.86857391,15.12047372,15.33594982,15.52393808,15.69047319,15.97508693,
         6.879965975,7.787598747,8.323445208,8.702142704,8.993818523,9.230291143,9.428689398,9.599282989,9.74870767,9.881494879,10.00087383,10.10922519,10.20835326,10.29965742,10.38424429,10.4630037,10.53666157,10.60581764,10.67097296,10.73255029,10.99775537,11.21120643,11.38941544,11.54212693,11.67556201,11.79392904,11.99656868,
         5.967461255,6.671869038,7.086787821,7.380127537,7.606271802,7.789808767,7.943953941,8.076625487,8.192938806,8.296387449,8.389461654,8.473997918,8.551388707,8.622714433,8.688829869,8.750422649,8.808053993,8.862187774,8.913211699,8.961453043,9.169433961,9.337070255,9.477185592,9.597360799,9.702442904,9.795715075,9.955508674,
         5.415107293,6.001358866,6.34576596,6.589170199,6.776867151,6.929271114,7.057336016,7.167618995,7.264354101,7.350432283,7.427914075,7.498319115,7.562799728,7.622250125,7.677377889,7.728752348,7.776838262,7.822019857,7.86461834,7.904904909,8.078716175,8.21895987,8.336281128,8.436979125,8.525085016,8.603331499,8.737476085,
         5.047627148,5.557721864,5.856596367,6.067679471,6.230438105,6.362610631,6.47370029,6.569390444,6.653348758,6.728078532,6.795363589,6.856519328,6.912543135,6.96420898,7.012129312,7.056796936,7.098614171,7.137913648,7.174973465,7.210028446,7.361342544,7.483523148,7.585795656,7.673622019,7.750499394,7.818799656,7.935947601,
         4.786614749,5.243985016,5.511298599,5.699940616,5.845356813,5.963440335,6.06269389,6.148197898,6.223228956,6.29002252,6.350171097,6.404848771,6.454945661,6.501152432,6.544015586,6.583974851,6.62138921,6.656555466,6.689721771,6.721097666,6.856575129,6.966022901,7.057676628,7.136413699,7.205357845,7.266628188,7.371758593,
         4.59214685,5.011055819,5.255328141,5.427566715,5.560291288,5.668053034,5.758626963,5.83665485,5.905128663,5.966088832,6.020988489,6.070898726,6.116631441,6.158816529,6.197952356,6.234439895,6.268606473,6.300722713,6.331014867,6.359673989,6.483446938,6.583472016,6.667258951,6.739255871,6.802312081,6.858360891,6.954556604,
         4.441892829,4.83160655,5.058379373,5.21814827,5.341216055,5.44111762,5.525076906,5.597403444,5.660873566,5.717379895,5.768269904,5.814536572,5.856932457,5.896041333,5.932325027,5.966155078,5.997834768,6.027614821,6.055704852,6.082281854,6.19707816,6.289869268,6.367611988,6.434427162,6.492954638,6.544985742,6.634303513,
         4.322439716,4.689289461,4.902352703,5.052345586,5.167837221,5.261568083,5.340331371,5.408176894,5.46771238,5.52071486,5.568449149,5.611847111,5.651614858,5.688300057,5.722335921,5.754070937,5.783789544,5.811726879,5.83807951,5.863013408,5.970721503,6.05779528,6.130757293,6.193471105,6.248411793,6.29725894,6.381121579,
         4.225267804,4.57375708,4.775808248,4.917944261,5.027343568,5.116109657,5.190690366,5.254927253,5.311292832,5.361471421,5.406661523,5.447745962,5.485393573,5.52012304,5.552344603,5.582388233,5.61052324,5.636972234,5.661921302,5.685527556,5.787505414,5.869953746,5.93904572,5.998437794,6.050472355,6.096738962,6.176178937,
         4.144716439,4.478155316,4.671177962,4.806869412,4.911269196,4.995959297,5.067104823,5.128376833,5.182137134,5.229994115,5.273091974,5.312273359,5.348176568,5.381296534,5.412024667,5.440675766,5.467506733,5.492729909,5.516522786,5.539035212,5.636289998,5.714923476,5.780821963,5.837471785,5.887106261,5.93124091,6.00702519,
         4.076882859,4.397771259,4.583263926,4.713578462,4.813805372,4.895092204,4.963368557,5.022163459,5.073746484,5.119662766,5.161011242,5.198601082,5.233045128,5.264818516,5.294296958,5.321782597,5.347521991,5.371718915,5.394543692,5.416140109,5.509438206,5.584874108,5.648094618,5.702443933,5.750064224,5.792409112,5.865123128,
         4.018991766,4.329261458,4.508382382,4.634145619,4.730839241,4.809243554,4.875089079,4.931784783,4.98152227,5.025793185,5.065658202,5.101898177,5.135104423,5.16573533,5.194153328,5.220649859,5.245462724,5.268788451,5.290791296,5.311609915,5.401547287,5.474265986,5.535209951,5.587602964,5.633509949,5.674332067,5.74443308,
         3.969017149,4.270190311,4.443852296,4.565715171,4.659379994,4.735312715,4.799073447,4.853968389,4.902122392,4.944981313,4.983573061,5.018654247,5.050797749,5.080447614,5.107954897,5.133601869,5.157618833,5.180196107,5.201492747,5.221643015,5.308691798,5.379074097,5.43805992,5.488769772,5.533202313,5.57271368,5.640564913,
         3.92544628,4.218742726,4.387677338,4.506161727,4.597202365,4.670993184,4.732946846,4.786280615,4.833061579,4.874695966,4.912183323,4.946259278,4.977480748,5.006279362,5.032996328,5.057905976,5.081232116,5.103159687,5.123843242,5.143413237,5.227953524,5.29630616,5.353590425,5.402837307,5.445988005,5.484359614,5.550254036,
         3.887127379,4.17353907,4.338341272,4.453871725,4.542617439,4.614534729,4.674907453,4.726875187,4.772454553,4.813017155,4.849537762,4.882733663,4.913147828,4.941201033,4.967225881,4.991489759,5.0142108,5.035569245,5.055715707,5.074777315,5.15711943,5.223692957,5.279485336,5.327449233,5.369475571,5.40684727,5.471024572,
         3.853168335,4.13351241,4.294672336,4.407598686,4.494320864,4.564585884,4.623564152,4.674326808,4.718846018,4.758462882,4.794130338,4.826549516,4.856251096,4.883646292,4.909060118,4.932753847,4.954940608,4.975796496,4.995468657,5.014081283,5.094481744,5.159483361,5.213957309,5.260787169,5.301819507,5.338307092,5.400965833,
         3.82286764,4.097824951,4.255751006,4.366364813,4.451289687,4.520086925,4.577826259,4.627518099,4.67109516,4.709871466,4.74478058,4.776509288,4.80557736,4.832387519,4.857258046,4.880444782,4.902156413,4.922565355,4.941815673,4.960028953,5.038702142,5.102305084,5.15560567,5.201426103,5.241573531,5.27727393,5.338580366,
         3.795666195,4.065809836,4.220845797,4.329392529,4.412710606,4.480195445,4.536826857,4.585561005,4.628295358,4.666319756,4.700550446,4.7316614,4.760162638,4.786449298,4.81083364,4.833566652,4.85485305,4.874861961,4.893734694,4.911590507,4.988717361,5.051067888,5.10331763,5.148233899,5.187588595,5.222583722,5.282678394,
         3.771113008,4.036929789,4.18936768,4.296055884,4.377929046,4.444233546,4.4998684,4.547741028,4.589717228,4.627065103,4.660685341,4.691240393,4.719231519,4.745047034,4.768993789,4.791318409,4.812222038,4.831870847,4.85040367,4.867937668,4.943672246,5.004894931,5.056198208,5.100300017,5.138940544,5.173300228,5.232302965,
         3.748840324,4.010747174,4.160837105,4.265845421,4.346412355,4.41164967,4.466383401,4.513476938,4.554767465,4.591503446,4.624571508,4.654623698,4.682153354,4.707542627,4.73109348,4.753048592,4.773605882,4.792928848,4.811154084,4.828396861,4.902871382,4.963073172,5.013519618,5.056884012,5.094877859,5.128662097,5.186675871,
         3.728545314,3.986901979,4.134859761,4.23834235,4.317722755,4.38199056,4.43590556,4.482291175,4.522958615,4.559138515,4.591704737,4.621299877,4.648410082,4.673411907,4.696602872,4.718222076,4.738464508,4.757491236,4.775436823,4.792414819,4.865743585,4.925016957,4.974684094,5.017377721,5.054783283,5.088043991,5.145157925,
         3.709976378,3.965095375,4.111108487,4.213199287,4.291497175,4.354880353,4.40804823,4.453787785,4.493886545,4.529558887,4.561667034,4.59084496,4.617572255,4.642220368,4.66508277,4.686395292,4.706350248,4.725106494,4.742796736,4.759532955,4.831815426,4.890240872,4.939196189,4.981277083,5.018145211,5.050927608,5.107219343,
         3.692922774,3.945077272,4.089309595,4.190125699,4.267432007,4.330004779,4.382488153,4.427635751,4.467213417,4.502420646,4.534109,4.562904563,4.589280917,4.613604838,4.636166087,4.6571975,4.676888945,4.695397248,4.712853418,4.729367997,4.800691243,4.85833924,4.906641844,4.948160836,4.984536081,5.016879788,5.072417365,
         3.677206658,3.926636797,4.069232398,4.168876749,4.245271435,4.30709907,4.358953011,4.403556233,4.442654662,4.477434112,4.508736351,4.53718021,4.563233751,4.587259453,4.609543665,4.630316474,4.649765497,4.668045694,4.685286512,4.701597173,4.772037839,4.828970441,4.876672379,4.917674242,4.953595847,4.985535769,5.040379141,
         3.662676923,3.909594908,4.050681097,4.149244677,4.224798414,4.285938602,4.337211792,4.381312705,4.419968901,4.454353583,4.485299488,4.513418754,4.539174356,4.562924808,4.584953314,4.605487424,4.624712677,4.642782316,4.659824344,4.675946765,4.745572661,4.801844779,4.84899212,4.889516483,4.92501919,4.956586233,5.010788492,
         3.649204356,3.893798615,4.033488443,4.131052046,4.2058276,4.266331584,4.317067265,4.360703237,4.398950075,4.432969316,4.463585342,4.491404106,4.51688387,4.540379482,4.562171237,4.582484337,4.601502399,4.619377073,4.63623503,4.652183146,4.721054551,4.776715006,4.823348711,4.863430821,4.898545532,4.929767188,4.983375569,
         3.594286943,3.829465752,3.963495696,4.057004362,4.128623205,4.186545645,4.235099731,4.276848269,4.313433037,4.345968318,4.375244639,4.401842874,4.426202192,4.448662575,4.469492516,4.488907692,4.507083929,4.524166419,4.540276419,4.55551623,4.621321371,4.674495644,4.719041359,4.757325464,4.790862608,4.820679819,4.871873043,
         3.523258326,3.746395578,3.873180329,3.961492845,4.029062898,4.083671791,4.129423987,4.168747232,4.20319542,4.233822434,4.261375503,4.286403409,4.309320875,4.330448837,4.350040664,4.368299826,4.385392151,4.401454544,4.41660132,4.4309289,4.49278431,4.542755407,4.584610607,4.620577627,4.6520816,4.680088633,4.728168685,
         3.498975151,3.718031072,3.842357677,3.928905291,3.995098812,4.048580223,4.093378388,4.131875363,4.165595298,4.195571624,4.222536898,4.247029019,4.269454419,4.290127571,4.309296706,4.327161147,4.343883325,4.359597325,4.374415103,4.388431078,4.4489371,4.497813696,4.538749519,4.573924767,4.604734002,4.632122518,4.679138908,
         3.479324968,3.695091444,3.817435626,3.902558945,3.967640921,4.020211423,4.06423847,4.102067343,4.135198243,4.164648125,4.191137727,4.215196179,4.237223228,4.257528133,4.276354983,4.293899753,4.310322131,4.32575393,4.340305196,4.354068732,4.413481442,4.461471124,4.501661908,4.536195526,4.56644178,4.593329105,4.639483666,
         3.463097938,3.676156895,3.796868396,3.880817945,3.944983361,3.99680236,4.040192953,4.077470187,4.110114572,4.139129513,4.165226023,4.188926016,4.210623737,4.230624151,4.249167936,4.266448309,4.282622698,4.297821041,4.31215181,4.325706479,4.384214427,4.431470018,4.471044086,4.505046572,4.534826803,4.561299266,4.606740499,
         3.449471583,3.660263136,3.779606592,3.86257203,3.925968555,3.977156817,4.020013001,4.056826867,4.08906245,4.117711817,4.143477843,4.166876401,4.188297127,4.208041391,4.226347012,4.243404896,4.259370578,4.274372422,4.288517583,4.301896415,4.359642528,4.406279844,4.445334428,4.478889489,4.508277137,4.534400116,4.579240462,
         3.437867289,3.646732342,3.764912826,3.847041198,3.909783371,3.960434599,4.002835574,4.039254594,4.071141711,4.09947937,4.124963533,4.148104942,4.169289319,4.188814979,4.206917311,4.223785258,4.239572742,4.254406792,4.26839344,4.281622089,4.338717361,4.384826326,4.423436898,4.456609501,4.485661547,4.511485762,4.555812432,
         3.4191576,3.624925085,3.741234333,3.822014814,3.883702547,3.933487814,3.975154331,4.010935947,4.042260266,4.070094272,4.09512283,4.117848436,4.138650522,4.157822492,4.175595828,4.192156311,4.207655274,4.222217593,4.235947492,4.248932847,4.304973334,4.350225583,4.388115948,4.420668038,4.449175512,4.474514885,4.518007889,
         3.404730622,3.608116731,3.722986137,3.802728479,3.863603353,3.912720496,3.953819921,3.989109042,4.019998236,4.047442624,4.072118548,4.094522176,4.115028104,4.133925964,4.151444233,4.167766264,4.183041397,4.197392849,4.210923457,4.223719915,4.278940962,4.323527098,4.36085716,4.392926302,4.421009801,4.445971616,4.488815284,
         3.39326712,3.594765415,3.708492521,3.787410563,3.847639489,3.896225302,3.936873428,3.971770365,4.002312857,4.029446636,4.053841296,4.075987993,4.096257494,4.114936444,4.132250937,4.148382402,4.163478596,4.177661425,4.191032621,4.203677945,4.258242939,4.302295298,4.339176067,4.370857742,4.398600951,4.423259634,4.465581787,
         3.383939166,3.583904178,3.69670288,3.774950472,3.834653634,3.882806682,3.923086996,3.957664115,3.987923725,4.014803944,4.038968894,4.060905661,4.080981911,4.099481857,4.116629666,4.132605199,4.147554932,4.161599703,4.174840349,4.187361867,4.241389092,4.285003505,4.321515375,4.352878732,4.38034225,4.404751688,4.446644845,
         3.376200927,3.57489589,3.686925114,3.764616658,3.82388349,3.871677168,3.911651876,3.945963124,3.975987452,4.00265668,4.026630402,4.048392339,4.068307586,4.086658349,4.103667194,4.119512689,4.134340244,4.148269817,4.161401498,4.173819658,4.227397637,4.270645855,4.306849037,4.337945871,4.36517509,4.389375647,4.430909105,
         3.369677966,3.567303684,3.678684742,3.755907628,3.814806492,3.862296938,3.902013647,3.936100332,3.965925845,3.992416707,4.016228707,4.037842734,4.057621722,4.075846188,4.09273735,4.108472688,4.123196718,4.137028652,4.150067957,4.162398472,4.215595267,4.258532488,4.29447332,4.325343501,4.35237337,4.376396126,4.417623243,
         3.359288245,3.555213396,3.665562891,3.742039343,3.800351711,3.847358506,3.886663434,3.92039148,3.949899288,3.976104968,3.999658259,4.021035559,4.040596365,4.05861851,4.075321076,4.090879808,4.105437802,4.119113086,4.132004133,4.144193938,4.19677825,4.239215139,4.274733468,4.30523832,4.331946631,4.355682406,4.39641468,
         3.351382019,3.54601515,3.655580291,3.731488699,3.789354355,3.835992469,3.874983257,3.908437504,3.937702594,3.963690257,3.98704565,4.008241758,4.027635475,4.045502597,4.062060583,4.077483864,4.091914454,4.105469485,4.118246675,4.130328377,4.182441644,4.224493143,4.259685609,4.289908384,4.316368178,4.339881973,4.380231085,
         3.342527557,3.535715788,3.644403089,3.719675204,3.777040057,3.823264508,3.861902556,3.895049133,3.924041287,3.94978363,3.972916197,3.993908171,4.013113534,4.03080581,4.047200642,4.062470997,4.07675768,4.09017682,4.102825291,4.114784729,4.166364667,4.207979098,4.242801492,4.27270354,4.298880469,4.322141374,4.362053453,
         3.332543466,3.524105066,3.631803193,3.70635758,3.763156955,3.808913859,3.847152839,3.879951021,3.908633847,3.93409793,3.956977557,3.977737634,3.996728877,4.014222251,4.030431367,4.045527537,4.059650214,4.072914395,4.085416006,4.097235877,4.148206161,4.189319926,4.223717642,4.253251067,4.27910245,4.302071953,4.341479659,
         3.325917391,3.51640095,3.623442928,3.697520761,3.753944309,3.799390181,3.837363444,3.869929449,3.898405961,3.923684307,3.94639497,3.96700003,3.98584804,4.003208276,4.019293001,4.034272435,4.048285133,4.061445346,4.073848371,4.085574503,4.136134768,4.17691112,4.211022131,4.240306316,4.265937289,4.28870926,4.327774537
)
D0.01=c(9.92873251,12.39240556,13.83087964,14.83008295,15.58801435,16.19469399,16.69827811,17.12738812,17.50034825,17.82956037,18.12378835,18.38944311,18.631349,18.85322329,19.0579881,19.24798026,19.42509657,19.59089687,19.74667866,19.89353234,20.52203222,21.02348146,21.43938716,21.79395244,22.10247625,22.37522158,22.84024676,
        5.842761827,6.975953431,7.640811001,8.106422636,8.462097982,8.748431034,8.987221006,9.191486556,9.369603019,9.527264707,9.668512369,9.796312994,9.91290683,10.02002521,10.11903276,10.2110234,10.29688699,10.37735669,10.45304351,10.52446172,10.8308386,11.07605696,11.27990176,11.4539691,11.60562091,11.73981405,11.96884887,
        4.605449222,5.365405252,5.810438305,6.122915763,6.362343932,6.555639804,6.717244519,6.855787675,6.976827924,7.084150241,7.180444742,7.267689801,7.347381479,7.420677652,7.488492213,7.551558707,7.610474564,7.665732597,7.717743926,7.766854968,7.977889641,8.147190636,8.288173817,8.408727302,8.513872355,8.606997567,8.766112848,
        4.033305447,4.628688847,4.975949174,5.219804376,5.406843617,5.558028898,5.684580114,5.793195465,5.888188411,5.972496441,6.048208063,6.116859936,6.179614719,6.237372769,6.290845136,6.340602887,6.387111387,6.430754733,6.471853521,6.510678037,6.677702398,6.811917806,6.923830457,7.019628775,7.10325799,7.177383944,7.304156114,
        3.708500315,4.213570187,4.506872555,4.712651407,4.870493627,4.998127196,5.105017347,5.196806838,5.277126576,5.348448173,5.41252856,5.470660373,5.523821688,5.572770013,5.618103679,5.660303318,5.699760686,5.736799191,5.771688842,5.804657328,5.94659501,6.060776783,6.156069692,6.23770197,6.309009709,6.372248957,6.480476402,
        3.500508835,3.949216521,4.208723456,4.390561871,4.529985775,4.642721155,4.737145358,4.818245525,4.889227745,4.952273116,5.00893143,5.060342617,5.107369067,5.150678621,5.190798766,5.228153221,5.263087357,5.29588631,5.326788145,5.355993628,5.481790236,5.583059483,5.667626289,5.740106809,5.803448019,5.859643731,5.955863579,
        3.356387531,3.766826673,4.003333881,4.168834578,4.295658224,4.39817982,4.484042039,4.557788783,4.622338584,4.679675644,4.731209193,4.777975419,4.820758025,4.860163801,4.896671947,4.930667356,4.962463731,4.992320045,5.020452518,5.047043491,5.161611736,5.253883281,5.330966235,5.397054808,5.454827243,5.506095969,5.593909552,
        3.250821981,3.633688184,3.853598728,4.007286631,4.124982963,4.22009384,4.299734884,4.368131821,4.427996599,4.481171855,4.52896567,4.572339516,4.612020379,4.648571015,4.682435766,4.713971477,4.743468959,4.771168263,4.797269797,4.821942557,4.928263723,5.013916251,5.085487102,5.146863146,5.200526582,5.248157349,5.329758786,
        3.170251999,3.532358548,3.73976109,3.884533333,3.995331201,4.084833926,4.159761695,4.224101427,4.280409937,4.330423497,4.375374149,4.416167158,4.453486826,4.487862745,4.519712993,4.54937327,4.577117119,4.603170315,4.627721326,4.650929069,4.750945506,4.831530874,4.898877279,4.956638376,5.007147414,5.051983556,5.128809038,
        3.106782704,3.452721863,3.650376996,3.788193738,3.893603997,3.978722486,4.049962297,4.111124848,4.164646419,4.212180602,4.254900305,4.293667073,4.329131983,4.361798806,4.392065163,4.420250278,4.446614234,4.471371669,4.49470174,4.516755498,4.611801575,4.68838735,4.752396046,4.80729866,4.855311656,4.897935114,4.970976348,
        3.055515078,3.388521701,3.578376455,3.710622435,3.811714037,3.893315396,3.961594517,4.020204762,4.071486181,4.117026342,4.157950921,4.195086523,4.229057674,4.260347498,4.289337256,4.316332989,4.341584008,4.365296039,4.387640781,4.408762986,4.499793856,4.573145218,4.634452428,4.687039755,4.733029777,4.773858947,4.843829408,
        3.013252144,3.335686988,3.519163586,3.646851593,3.744407321,3.823127226,3.888979349,3.945496242,3.994939431,4.038842595,4.078292847,4.114088265,4.146831684,4.176989364,4.204929193,4.23094644,4.255281608,4.278133135,4.299666621,4.320021664,4.407743847,4.478427497,4.537504869,4.588179917,4.632498175,4.67184385,4.739273892,
        2.977820802,3.291457423,3.469625049,3.593517253,3.688126775,3.764444517,3.828272366,3.883042498,3.93095118,3.973487306,4.011705935,4.046381427,4.078098581,4.107309629,4.134371337,4.15957001,4.183138821,4.205270143,4.226124498,4.245837191,4.330787529,4.399234548,4.456441186,4.505511026,4.548425291,4.586524559,4.65181903,
        2.947693292,3.253896731,3.427578705,3.548262499,3.640380639,3.714666188,3.776780846,3.830072102,3.876681168,3.918059143,3.955234037,3.988960189,4.019807175,4.048215382,4.074532185,4.099036316,4.121954761,4.143474764,4.16375256,4.182919826,4.265515481,4.332061188,4.387676651,4.435380499,4.477099497,4.514137259,4.577612094,
        2.921764717,3.221607325,3.391450671,3.509387985,3.59937267,3.671917359,3.732563935,3.784587502,3.830082212,3.870466863,3.906746339,3.939657863,3.969757994,3.997476988,4.02315419,4.047061855,4.069421672,4.090416501,4.110198905,4.128897459,4.209468819,4.274379024,4.328625086,4.375152831,4.415842334,4.451965509,4.513871896,
        2.899216488,3.193555602,3.360077747,3.4756382,3.563775995,3.634813204,3.694188142,3.745113354,3.789642321,3.829165917,3.864669037,3.89687411,3.926326437,3.95344752,3.978569754,4.001959796,4.023834754,4.044373694,4.063726003,4.082017572,4.16083062,4.224319484,4.277374946,4.322879766,4.362673567,4.398000783,4.458541647,
        2.879429401,3.168960951,3.332581992,3.44606582,3.532589613,3.602309094,3.660572187,3.71053684,3.754221037,3.792991286,3.827815034,3.859401796,3.888287049,3.914884648,3.939520926,3.962457648,3.983907923,4.004047504,4.023023005,4.040957971,4.118229906,4.180472436,4.232483494,4.277090701,4.316098297,4.350726678,4.410068244,
        2.861926512,3.147222967,3.308288525,3.419942835,3.505044385,3.573602444,3.630885369,3.680003052,3.722942235,3.761047976,3.795272369,3.826313558,3.854698374,3.880833941,3.905041252,3.927577766,3.94865307,3.968440001,3.987082728,4.004702733,4.08061315,4.141754143,4.192841818,4.236655191,4.274967302,4.308977344,4.367257441,
        2.846334565,3.127872388,3.286670147,3.396700696,3.480539733,3.548066616,3.604479132,3.652844555,3.695121922,3.732637271,3.766329078,3.796885406,3.824825414,3.850550258,3.874376193,3.896556862,3.917298724,3.93677203,3.955118782,3.972458627,4.047157679,4.10731826,4.157583837,4.200690265,4.238382871,4.271842013,4.329176158,
        2.832357305,3.110537201,3.267309119,3.375889008,3.458599959,3.525205314,3.580839848,3.628532788,3.670218436,3.707205852,3.740421353,3.770544002,3.79808611,3.823443503,3.846928208,3.868790455,3.889233916,3.90842653,3.926508363,3.943597425,4.017211892,4.076494382,4.126023458,4.168496396,4.205633753,4.238599043,4.29508499,
        2.819756622,3.094918732,3.249870205,3.357146418,3.438843458,3.504620438,3.559555536,3.606643806,3.647797334,3.684309931,3.717096995,3.746829507,3.774013626,3.799040391,3.822218032,3.843793715,3.863968605,3.882908566,3.900751925,3.917615221,3.990253102,4.048744703,4.097610251,4.139512345,4.176149265,4.208669379,4.264390564,
        2.808338972,3.080774453,3.234081297,3.340179679,3.420960588,3.485988994,3.540291957,3.586833673,3.627506168,3.663589483,3.69598916,3.725368876,3.752229241,3.776956968,3.799856859,3.821173314,3.841105235,3.859816608,3.877444193,3.894103199,3.965857232,4.023632853,4.071897581,4.113282675,4.149466284,4.181583082,4.236611277,
        2.797945426,3.067905393,3.219719248,3.324748358,3.404697504,3.469046205,3.522775131,3.56882047,3.60905605,3.644749415,3.676797162,3.705856346,3.732422537,3.756878528,3.779526006,3.800606862,3.820317944,3.838821537,3.856252975,3.872726262,3.943676659,4.000801113,4.048519293,4.089434003,4.125205106,4.156954842,4.211352223,
        2.78844427,3.056146798,3.206599348,3.310653474,3.389844153,3.453572991,3.506778368,3.552370948,3.592207967,3.627545582,3.659272236,3.68803895,3.7143367,3.738544704,3.760961814,3.781827632,3.801337135,3.819651057,3.836903431,3.853207165,3.923423764,3.979953498,4.02717241,4.067657354,4.103051516,4.134465792,4.188286571,
        2.779725427,3.045361086,3.194567401,3.297728949,3.37622523,3.439386524,3.492112506,3.537290474,3.576762483,3.611774268,3.643206812,3.671705612,3.697757442,3.721738248,3.743944288,3.764613069,3.783937855,3.802077961,3.819166232,3.83531457,3.904858542,3.960843014,4.007604094,4.047694877,4.082743279,4.113849805,4.167141529,
        2.771696191,3.035432472,3.183493684,3.285835088,3.363693293,3.426333048,3.478618462,3.523415372,3.562551884,3.597264163,3.628426339,3.656678836,3.682504566,3.706276473,3.72828843,3.748776021,3.767930936,3.785911189,3.80284853,3.818853939,3.887779162,3.943261947,3.989601709,4.029329712,4.06405984,4.094883048,4.147687645,
        2.764277935,3.026262822,3.173268281,3.274853542,3.352123448,3.414282323,3.466161493,3.51060701,3.549434124,3.583870178,3.614782985,3.642808293,3.668425459,3.692004656,3.713837559,3.734157983,3.753156167,3.770988922,3.787786993,3.803660507,3.872014681,3.927034363,3.972985146,4.012378168,4.046814374,4.077375914,4.129730543,
        2.757403537,3.017768418,3.163797448,3.26468339,3.341409196,3.403123305,3.45462672,3.498747197,3.537288101,3.571468616,3.602150715,3.629965824,3.655390011,3.678790889,3.700458103,3.720623827,3.739476961,3.757173205,3.773842374,3.789593807,3.857419358,3.912010265,3.957600846,3.996683628,4.030847588,4.061166731,4.113104477,
        2.751015352,3.009877404,3.155000744,3.255238047,3.33145918,3.392760736,3.443915597,3.487734551,3.526009938,3.559953377,3.590421427,3.618041504,3.643286627,3.666522036,3.688035491,3.708057649,3.726776165,3.744345711,3.760895238,3.776533357,3.843868185,3.89806099,3.943317088,3.982111744,4.016022835,4.046116812,4.097667258,
        2.724834419,2.977563921,3.118992761,3.216584415,3.290747121,3.350365924,3.400098971,3.442687841,3.479879917,3.512855974,3.542450494,3.569274557,3.593788748,3.616348636,3.637234306,3.656670223,3.674838979,3.691891047,3.707951864,3.723127069,3.788456616,3.841021898,3.884910032,3.922525922,3.955402186,3.984574462,4.034538996,
        2.690627484,2.935410622,3.072056318,3.166224079,3.237723397,3.295165084,3.343058623,3.384055953,3.419846253,3.451570378,3.48003425,3.505827817,3.529395595,3.551080647,3.571153142,3.589829547,3.607285909,3.623667284,3.63909457,3.653669563,3.716397654,3.766849683,3.808960188,3.845043226,3.87657297,3.904545246,3.952443504,
        2.678840907,2.920903924,3.055913684,3.148911004,3.219500192,3.276198116,3.323463346,3.363917129,3.399228723,3.430525323,3.458603083,3.484044725,3.507289273,3.528675517,3.548470237,3.566887171,3.584100131,3.600252324,3.615463098,3.62983294,3.691671506,3.741400448,3.782902306,3.818460186,3.849528347,3.877089054,3.924278144,
        2.669268012,2.909128726,3.042814616,3.134865089,3.204718221,3.260814776,3.307572083,3.347586532,3.382511246,3.413462361,3.441228122,3.466385403,3.489368782,3.510513593,3.530083876,3.548291158,3.565307447,3.581274452,3.596310271,3.610514332,3.671633978,3.720778354,3.761788015,3.796921084,3.827615753,3.854843344,3.901458227,
        2.661338816,2.89938015,3.031972841,3.123241712,3.192487424,3.248087835,3.294426186,3.33407832,3.368684027,3.399350304,3.426858862,3.451781742,3.474549852,3.49549567,3.514880974,3.532915468,3.549769668,3.56558405,3.580475677,3.594543106,3.6550702,3.703732677,3.744336495,3.779119201,3.809505757,3.836458478,3.882599396,
        2.654663517,2.891176584,3.022851367,3.113464181,3.182200192,3.237384388,3.28337136,3.322719683,3.357057943,3.387485455,3.414778441,3.439504884,3.462092605,3.482871687,3.502102007,3.519991737,3.536710143,3.552396664,3.567167498,3.581120466,3.641151163,3.689409906,3.729673661,3.76416274,3.794291027,3.821013297,3.866756728,
        2.648966522,2.884177783,3.015070968,3.105125327,3.173427593,3.228257697,3.273945809,3.313035789,3.34714667,3.377371226,3.404480998,3.42904051,3.451474957,3.472112379,3.491211034,3.508977792,3.525580851,3.54115877,3.555827008,3.569682763,3.629291885,3.67720775,3.717182679,3.751422341,3.781331214,3.807857672,3.853263278,
        2.639757238,2.872869004,3.002502282,3.091656828,3.159260516,3.213520552,3.258727696,3.297402054,3.331147244,3.361045476,3.38786074,3.41215198,3.434340151,3.454749999,3.473637171,3.491206433,3.507624267,3.523027811,3.537531332,3.551231026,3.61016348,3.657529079,3.697040491,3.730879853,3.760436535,3.786648638,3.831511757,
        2.63263559,2.864127993,2.992790065,3.081251366,3.14831714,3.202138449,3.246975623,3.285330425,3.318794573,3.348442116,3.375031219,3.399116513,3.421115683,3.441350931,3.460075889,3.477493702,3.493769527,3.509039404,3.523416685,3.536996789,3.5954109,3.642355151,3.681511714,3.715044642,3.74433171,3.770303141,3.814750841,
        2.626964032,2.857169456,2.985060058,3.072970959,3.139609871,3.193083199,3.23762707,3.275728653,3.308970196,3.338419259,3.364829368,3.388751727,3.410601416,3.430698615,3.449295355,3.466593489,3.482757122,3.497921422,3.512199012,3.525684696,3.583689745,3.630301679,3.669178478,3.702469869,3.731544449,3.75732621,3.80144651,
        2.622340618,2.851498664,2.978761702,3.066225067,3.132517052,3.185707695,3.230013405,3.267909466,3.300970411,3.330258514,3.356523519,3.380313841,3.402042437,3.422027839,3.440520774,3.457722045,3.473794897,3.488873789,3.503070752,3.516480089,3.57415455,3.620498117,3.659149106,3.692245613,3.721148789,3.746777577,3.790633851,
        2.618499383,2.846788457,2.973531026,3.060623377,3.126627874,3.179584363,3.223692884,3.26141885,3.294330388,3.323485381,3.349630435,3.373311644,3.394940206,3.414833284,3.433240519,3.450361844,3.466359792,3.481368231,3.495498701,3.508845088,3.566247135,3.612369742,3.650834928,3.683771153,3.712533409,3.738036461,3.781675776,
        2.615257325,2.842813837,2.969117787,3.055897582,3.121659981,3.174419362,3.218361957,3.255944852,3.288730768,3.317773883,3.343818154,3.36740772,3.38895229,3.408767873,3.427103197,3.444157457,3.460092586,3.475041956,3.48911669,3.502410324,3.559584224,3.605521942,3.643831766,3.676634043,3.705278581,3.730676636,3.774134841,
        2.61008565,2.836475237,2.962080792,3.048363145,3.113740426,3.166186421,3.209865342,3.247221001,3.279807498,3.3086731,3.334557543,3.358001841,3.379413334,3.399106189,3.417327676,3.434275816,3.450111582,3.464967554,3.478954193,3.492164475,3.548978229,3.594624487,3.63268967,3.665281218,3.693740698,3.718973795,3.762147659,
        2.606143764,2.831645284,2.956719598,3.042623767,3.107708431,3.159916457,3.203395286,3.240578613,3.273013969,3.301745118,3.327508576,3.350842978,3.372153856,3.391753973,3.409889488,3.426757525,3.442518328,3.457303873,3.471224116,3.484371606,3.540914389,3.586341776,3.624223541,3.656657311,3.684978393,3.710088244,3.753049915,
        2.601722484,2.826229358,2.950708956,3.03618998,3.100947433,3.152889524,3.196144892,3.233135888,3.265402675,3.293983967,3.319612668,3.342824743,3.364023697,3.383520716,3.401560712,3.418339806,3.434017422,3.448724857,3.4625715,3.475649425,3.531892443,3.577078258,3.614757984,3.64701826,3.67518739,3.700162103,3.742891495,
        2.596728712,2.820113974,2.943923321,3.02892777,3.093316963,3.144959993,3.187964272,3.224739341,3.256817042,3.285230382,3.310708185,3.333783397,3.354857233,3.374239098,3.392172494,3.408852407,3.424437333,3.439057805,3.452822571,3.465823163,3.52173365,3.566652384,3.604109412,3.636178969,3.664181467,3.68900831,3.731484256,
        2.593409544,2.816050393,2.939415133,3.024103644,3.088248879,3.139693945,3.182532151,3.219164523,3.251117373,3.279419914,3.304798254,3.327783335,3.348774847,3.36808101,3.385944388,3.402559213,3.418083363,3.432646861,3.446358029,3.459308041,3.515001534,3.559746645,3.597059409,3.629005816,3.656901038,3.681632947,3.72394677)
D0.05=c(4.303129363,5.418385678,6.065414931,6.513568199,6.852924503,7.12423992,7.349252288,7.540855546,7.707293063,7.854138084,7.98532574,8.103732629,8.211522108,8.310360105,8.401555455,8.486154272,8.565005233,8.638805884,8.708136195,8.773483343,9.053041586,9.275935504,9.460674678,9.618051625,9.754891299,9.875774819,10.0816753,
        3.182790038,3.86687124,4.262988208,4.53861968,4.748330119,4.916683644,5.056789598,5.17644212,5.28063837,5.372766653,5.455225992,5.529774613,5.597737946,5.6601389,5.71778274,5.771314282,5.82125754,5.868043889,5.912032521,5.953525566,6.131369768,6.273536258,6.391599721,6.492333332,6.580032316,6.657586321,6.789846716,
        2.776748311,3.310665748,3.61797283,3.831844355,3.994790712,4.125809765,4.23501157,4.328401562,4.40983009,4.48190905,4.546489005,4.604927283,4.658247955,4.707242011,4.752532658,4.794619328,4.833908199,4.870733893,4.905375228,4.938066893,5.078355797,5.19069162,5.284105352,5.363892663,5.433417524,5.494946285,5.599974642,
        2.570865558,3.030529626,3.293450439,3.476189773,3.615414638,3.727406714,3.820802312,3.900722475,3.97044746,4.032201414,4.087559897,4.137678538,4.183429329,4.225485924,4.264379206,4.300534733,4.334298697,4.365956386,4.39574558,4.423866482,4.544632243,4.641440753,4.722012949,4.790881433,4.850928249,4.904096697,4.994912596,
        2.447183477,2.863032526,3.099577545,3.263701029,3.388671378,3.489185619,3.573016789,3.644765791,3.707376341,3.762842916,3.812577697,3.857616158,3.898739479,3.936551094,3.971526532,4.004046974,4.034422526,4.06290875,4.08971867,4.11503166,4.223789609,4.311033006,4.383685848,4.445815205,4.500008472,4.548011108,4.630040274,
        2.364887172,2.751976256,2.971126674,3.122916997,3.238407786,3.331265325,3.40869985,3.474972304,3.532805896,3.584044264,3.629992052,3.671605487,3.709605746,3.744549789,3.776876447,3.806937444,3.835018897,3.861356587,3.886147041,3.909555738,4.010159951,4.090897353,4.158156988,4.215692579,4.265892778,4.310369373,4.386396782,
        2.306260237,2.673079821,2.879931242,3.02297191,3.131717923,3.219114269,3.291976835,3.354327988,3.40873593,3.456938094,3.500163289,3.53931178,3.575062307,3.60793892,3.638354433,3.666639663,3.693063684,3.717848203,3.741178008,3.763208677,3.857905278,3.933920982,3.997261582,4.051455773,4.098749201,4.140657319,4.212309475,
        2.262407654,2.614197151,2.811908076,2.9484297,3.052139133,3.13544946,3.204885566,3.264293587,3.316127101,3.362044915,3.403219636,3.440510004,3.474563247,3.505878948,3.534850561,3.561793334,3.586963634,3.610572676,3.63279648,3.653783231,3.743999418,3.816428376,3.876788301,3.928438657,3.973517367,4.013467209,4.081780882,
        2.228384584,2.568596647,2.759255391,2.890737737,2.990547023,3.070688385,3.137463442,3.194583029,3.244412659,3.288550682,3.328126456,3.363966744,3.396694485,3.426790392,3.454632979,3.480525467,3.504714406,3.527402897,3.548760173,3.568928698,3.655629446,3.725239978,3.783255,3.832902244,3.876235646,3.914641257,3.980320212,
        2.201226775,2.532253332,2.717310275,2.844783821,2.941486202,3.0191,3.083750261,3.139040778,3.187267352,3.229980452,3.268275161,3.302952886,3.334617296,3.363734125,3.390670021,3.415718647,3.43911875,3.461066972,3.481727152,3.501237195,3.585106171,3.652443324,3.708564893,3.756593254,3.798515091,3.835670981,3.899216063,
        2.179050832,2.502615517,2.683117812,2.807328138,2.901498656,2.977050638,3.039966074,3.093762003,3.140677711,3.182224831,3.219470635,3.253195949,3.283988791,3.312302727,3.338494758,3.362850779,3.385603186,3.406943369,3.427030774,3.445999593,3.527539122,3.593003902,3.647564491,3.694257155,3.735013554,3.771137024,3.832917989,
        2.160603456,2.477988454,2.654716213,2.776219724,2.868288199,2.942126984,3.003599854,3.056152148,3.101976427,3.142552206,3.178923752,3.211854859,3.241920589,3.269564429,3.295135394,3.318912937,3.341124194,3.3619562,3.381564755,3.400080975,3.479671066,3.543567233,3.596818938,3.642390799,3.682168651,3.717424793,3.777722733,
        2.145018624,2.457203064,2.630752697,2.749975372,2.840271303,2.91266446,2.972919314,3.024420968,3.069322719,3.109077089,3.144709003,3.176967929,3.206418033,3.233494326,3.258539095,3.281826375,3.303578871,3.32397995,3.343182342,3.361314568,3.439249662,3.50181287,3.553951457,3.598569522,3.637514166,3.672031435,3.731065207,
        2.131678903,2.4394271,2.610264588,2.727539635,2.816321043,2.887478303,2.946691314,2.997293867,3.041405809,3.080456661,3.115454863,3.147137673,3.176059965,3.202649518,3.227242885,3.250109477,3.271468218,3.291499342,3.310352963,3.328155384,3.404668225,3.466084974,3.517265519,3.561062184,3.599288912,3.63316926,3.691112679,
        2.120132323,2.424052155,2.592548375,2.708141245,2.795613874,2.865702618,2.924014489,2.973839056,3.01726733,3.055709002,3.090158296,3.12134194,3.149806793,3.175974395,3.20017635,3.22267808,3.243695241,3.263405369,3.281956312,3.299472462,3.374750185,3.435170587,3.485518022,3.528600025,3.566201841,3.599527558,3.656521007,
        2.110040478,2.410623248,2.577078119,2.691203652,2.777534145,2.846690041,2.904214893,2.953359764,2.996190557,3.03409969,3.068069005,3.098816056,3.126880717,3.152679093,3.176538474,3.198720802,3.219438888,3.238867912,3.257153748,3.274419121,3.3486144,3.408161053,3.457777494,3.50023214,3.537285161,3.570123626,3.626282125,
        2.101144999,2.398793378,2.563452833,2.676287309,2.761612493,2.829947002,2.886778647,2.935324663,2.977628894,3.015068581,3.048614684,3.078976694,3.106688345,3.132160963,3.155718046,3.177618475,3.19807256,3.217253408,3.235305157,3.252349064,3.325588058,3.384362363,3.433332333,3.475231933,3.511799239,3.544206319,3.59962529,
        2.093245232,2.388293325,2.551361494,2.663051318,2.747484893,2.815090687,2.871307158,2.919321594,2.961158306,2.998181093,3.03135128,3.061371213,3.08876919,3.1139523,3.137240681,3.158890505,3.179109862,3.198070021,3.215913584,3.232760505,3.30514864,3.363235403,3.411629646,3.453034758,3.489169201,3.521191724,3.575951201,
        2.086182984,2.378911029,2.540559186,2.651227258,2.734864716,2.801819659,2.857486551,2.90502598,2.94644484,2.983094946,3.015929028,3.045643061,3.072760494,3.097684636,3.120732628,3.142158221,3.162167529,3.180930179,3.1985874,3.215257986,3.286884244,3.344355098,3.392233404,3.433195237,3.468941535,3.50061914,3.554786901,
        2.079831866,2.370477202,2.530850441,2.640600918,2.723523222,2.789893359,2.84506633,2.89217877,2.933221948,2.969536928,3.002068727,3.031507603,3.05837265,3.083063788,3.105895465,3.127119262,3.146939514,3.165524378,3.183013848,3.199525676,3.270465827,3.327381814,3.374795164,3.415357406,3.450753722,3.48212025,3.535754192,
        2.074089685,2.362855068,2.522077369,2.630999283,2.713275666,2.779117493,2.833844168,2.88057072,2.921274321,2.957286337,2.989544824,3.018734882,3.045371675,3.069852065,3.092488067,3.113529303,3.133178505,3.151602499,3.168940167,3.185308319,3.255627406,3.312040956,3.359033164,3.399233375,3.434312535,3.465397106,3.518547069,
        2.068872923,2.355932924,2.514111051,2.622281098,2.70397122,2.769333435,2.823654876,2.870030985,2.910426157,2.946162959,2.978173137,3.007137113,3.033566488,3.057855346,3.080313499,3.101188791,3.120682498,3.138960241,3.156159891,3.172397403,3.242151663,3.298108137,3.344717124,3.38458783,3.419378269,3.450206114,3.502915305,
        2.064112658,2.349618648,2.506845192,2.614329905,2.695485534,2.760410405,2.814362264,2.860418713,2.900532508,2.936018204,2.967801799,2.996559453,3.022799519,3.046913552,3.069209356,3.089933155,3.109284896,3.127429103,3.144502725,3.160620939,3.229859321,3.285398218,3.331657021,3.371226568,3.405753077,3.436346202,3.488652314,
        2.059751514,2.343835594,2.50019137,2.607048836,2.68771518,2.752239629,2.805853052,2.85161674,2.891472803,2.926728468,2.958304476,2.986873087,3.012939683,3.036893505,3.05904052,3.079625467,3.098847082,3.116868881,3.133826971,3.149835816,3.218601181,3.273757103,3.319694676,3.358987914,3.393272232,3.423649941,3.47558605,
        2.055741337,2.338519473,2.494075433,2.600356661,2.680573431,2.744729894,2.798032253,2.843526821,2.883145938,2.918190101,2.949575225,2.977969988,3.003877045,3.027683511,3.049693667,3.070150888,3.089252794,3.107161979,3.124013774,3.139921989,3.208252074,3.263055503,3.308697358,3.347736192,3.381797488,3.411976802,3.463572091,
        2.052041418,2.333615961,2.488434736,2.594184762,2.673987024,2.737804153,2.790819626,2.836065963,2.8754665,2.910315538,2.941524542,2.969758891,2.995518726,3.019189205,3.04107305,3.061412383,3.080403797,3.098209031,3.114962704,3.130778021,3.198706224,3.253184142,3.298552875,3.337356709,3.371211966,3.401207974,3.452488313,
        2.048617107,2.329078843,2.48321599,2.588474773,2.667893647,2.731396871,2.784146923,2.829163575,2.868361844,2.903030301,2.934076298,2.962162166,2.987785723,3.011330314,3.033097223,3.053327412,3.072216522,3.089925505,3.106588321,3.122317614,3.18987363,3.24405004,3.289165751,3.327751854,3.361416192,3.391242327,3.442230758,
        2.045438725,2.324868552,2.478373583,2.583176739,2.662239968,2.725451962,2.777955735,2.822759243,2.861769792,2.896270641,2.927165332,2.955113368,2.980610411,3.004038127,3.025696468,3.045825316,3.064619433,3.08223904,3.098817484,3.114466891,3.18167724,3.235573583,3.280454235,3.318838042,3.352324976,3.381993249,3.432710377,
        2.042480707,2.32095102,2.473868245,2.578247653,2.656980074,2.71992114,2.772195776,2.816800956,2.855636816,2.88998168,2.920735547,2.948555291,2.97393457,2.997253488,3.018810759,3.038845262,3.05755094,3.075087332,3.091587218,3.107162242,3.174050702,3.227686209,3.272347918,3.310543277,3.343864939,3.373386133,3.423850461,
        2.030312642,2.304844607,2.455348782,2.557988007,2.635361401,2.697189052,2.748521725,2.79231137,2.830428733,2.864131894,2.894306319,2.921598096,2.946492664,2.969363718,2.990504878,3.010150917,3.028492406,3.045686097,3.061862427,3.077131062,3.142693363,3.195253897,3.239013047,3.276431386,3.309071441,3.337985947,3.387407244,
        2.014303146,2.283675086,2.431016616,2.531373364,2.606962782,2.66732777,2.717422177,2.760139115,2.797310917,2.830169197,2.859580408,2.886176528,2.910432234,2.932712827,2.953305256,2.972438902,2.990299924,3.00704141,3.022790728,3.037654943,3.101466096,3.152606403,3.195172613,3.23156358,3.263302141,3.291414019,3.33945492,
        2.008757067,2.276347275,2.422596425,2.522164271,2.597136633,2.656995348,2.706660877,2.74900607,2.785850025,2.818415236,2.847561607,2.873916249,2.897950126,2.920025643,2.940427446,2.959383055,2.977077102,2.99366141,3.009262284,3.023985892,3.08718803,3.137834224,3.179985286,3.216018654,3.247443382,3.275275809,3.322836013,
        2.004241236,2.27038293,2.415743845,2.514669987,2.589140224,2.6485868,2.697903068,2.739945425,2.776522228,2.808848566,2.837779022,2.863936756,2.887789717,2.909697955,2.929944245,2.948754593,2.966312392,2.982768434,2.99824816,3.012857007,3.075562,3.125804769,3.167616845,3.203358201,3.234526645,3.262130859,3.309298497,
        2.000493004,2.265433936,2.410058428,2.508452368,2.582506012,2.641610527,2.690636823,2.732427674,2.768782544,2.800910393,2.829661398,2.855655447,2.879357989,2.901127128,2.921244085,2.939933614,2.957378076,2.973727413,2.989106348,3.003619711,3.065911003,3.115818007,3.157347926,3.192846215,3.22380133,3.25121558,3.298056454,
        1.997332002,2.26126138,2.405265403,2.503210809,2.576913233,2.635729269,2.684510937,2.72608955,2.762257088,2.794217354,2.822816817,2.848672612,2.872248086,2.893899701,2.913907371,2.932494795,2.949843468,2.966102612,2.981396346,2.995828989,3.057770498,3.107393568,3.14868487,3.183977594,3.214752295,3.242005896,3.288570439,
        1.994630262,2.257695846,2.401169967,2.498732206,2.572134504,2.63070395,2.679276449,2.720673538,2.756680814,2.788497679,2.816967442,2.842704889,2.866171572,2.887722552,2.907636631,2.926136603,2.943403226,2.959585106,2.974805847,2.989169332,3.050811113,3.100190845,3.141277632,3.176394168,3.207014239,3.234130153,3.28045788,
        1.990255019,2.251923311,2.394540109,2.491482212,2.564398574,2.622568599,2.670802155,2.711904985,2.747652378,2.779236631,2.807495946,2.833041313,2.856331389,2.877718969,2.897481055,2.915838983,2.932972316,2.949028666,2.964130804,2.978381902,3.03953651,3.088520633,3.129274896,3.164104959,3.194473618,3.221365682,3.267308435,
        1.986864913,2.247451853,2.389405046,2.485866938,2.558406825,2.616267245,2.664237944,2.705112463,2.740658129,2.772061749,2.800157584,2.82555369,2.848706485,2.869967018,2.889610897,2.907858332,2.924887961,2.940846627,2.955856457,2.970020077,3.030795359,3.079471352,3.119966585,3.154573485,3.184746302,3.211464009,3.257106958,
        1.9841609,2.243886163,2.385310472,2.48138951,2.553629119,2.611242489,2.659003347,2.699695526,2.735080019,2.766339268,2.794304394,2.819581124,2.842624094,2.863782962,2.883332228,2.901491206,2.918437797,2.934318234,2.949254128,2.963347669,3.023818989,3.072247985,3.11253555,3.14696353,3.176979337,3.203557271,3.248959924,
        1.981953845,2.240976343,2.381969243,2.477735892,2.549730403,2.607142039,2.654731481,2.695274654,2.730527389,2.761668575,2.789526778,2.814705826,2.837658906,2.858734543,2.878206334,2.896292863,2.913171432,2.928987774,2.943863082,2.957899191,3.018121324,3.066347766,3.106464997,3.140746217,3.170633239,3.197096534,3.242302137,
        1.980118281,2.238556679,2.379190969,2.474697876,2.546488528,2.603732317,2.651179086,2.691598195,2.726741191,2.757784014,2.785553109,2.810650729,2.833528858,2.854535079,2.873942242,2.891968324,2.908790128,2.924552975,2.93937771,2.953365871,3.013379908,3.061437135,3.101412045,3.135570632,3.165350041,3.191717551,3.236758536,
        1.978567696,2.236512944,2.37684443,2.472131965,2.543750393,2.600852336,2.648178497,2.688492695,2.723542867,2.754502464,2.782196144,2.807224831,2.830039494,2.850986925,2.870339341,2.888314209,2.905087912,2.920805421,2.935587288,2.949534801,3.009372371,3.057286053,3.097140208,3.131194737,3.160882834,3.187169071,3.232070399,
        1.976091678,2.233249955,2.373098159,2.468035468,2.539378844,2.596254163,2.64338755,2.683533998,2.718435687,2.749262104,2.77683506,2.801753363,2.824466366,2.845319599,2.864584272,2.882477038,2.899173611,2.914818405,2.929531505,2.943413803,3.002968128,3.050651289,3.090311466,3.124198814,3.153740205,3.179895872,3.224572871,
        1.974202328,2.230760518,2.370240146,2.464910269,2.53604372,2.592745996,2.639732117,2.679750354,2.714538504,2.745263039,2.772743602,2.797577391,2.82021253,2.840993587,2.860191008,2.878020827,2.894658247,2.91024726,2.924907595,2.938739841,2.998076661,3.045582683,3.08509374,3.118852543,3.148281123,3.174336391,3.21884093,
        1.97208102,2.227965882,2.367031887,2.46140207,2.532299766,2.588807619,2.635628201,2.675502246,2.710162647,2.740772494,2.768149004,2.792887574,2.815434949,2.836134624,2.855256189,2.873014981,2.889585637,2.905111673,2.919712419,2.933488126,2.992579102,3.039884748,3.079227042,3.112840326,3.142141183,3.16808278,3.212392092,
        1.969682247,2.224806263,2.363404797,2.457435862,2.528066879,2.584354682,2.630987794,2.67069845,2.705214004,2.735693738,2.762952134,2.787582557,2.810030203,2.830637354,2.849672635,2.867350604,2.883845254,2.899299568,2.913832426,2.927543698,2.98635426,3.0334311,3.072580544,3.106027464,3.13518227,3.160993876,3.205079957,
        1.968086233,2.222704348,2.360991997,2.454797457,2.525250976,2.581392241,2.627900441,2.667502165,2.701921093,2.73231398,2.759493493,2.78405165,2.806432619,2.826977881,2.845955419,2.863579274,2.880023013,2.895429267,2.909916617,2.923584681,2.982207032,3.029130112,3.068149851,3.10148482,3.130541312,3.156265402,3.200201198)
D0.1=c(2.920178591,3.720997324,4.181934752,4.500040277,4.740396537,4.93227645,5.091236394,5.226480418,5.343881769,5.447405423,5.539847617,5.623250387,5.699148172,5.768721741,5.832898182,5.892418082,5.947881957,5.999783167,6.048531751,6.094472017,6.290927209,6.447475848,6.577172438,6.687622278,6.783631577,6.868424641,7.012804848,
       2.353508809,2.912266791,3.231995409,3.453165462,3.620818059,3.755058694,3.866557702,3.961633603,4.044324954,4.117363307,4.182678747,4.24168339,4.295440189,4.344768438,4.390312384,4.432587394,4.472011911,4.508930126,4.543628423,4.576347532,4.716473634,4.828366327,4.921212293,5.000378702,5.069264967,5.130155814,5.233944497,
       2.131969635,2.598351766,2.863210519,3.04625791,3.185092975,3.296365645,3.388881531,3.46784711,3.536588416,3.597355048,3.651736968,3.70089793,3.74571437,3.786862175,3.824873119,3.860172824,3.893107052,3.923960356,3.952969619,3.980334056,4.097634088,4.191420187,4.269319615,4.335795364,4.393677762,4.444871075,4.532191007,
       2.015156525,2.433537091,2.669540679,2.832356396,2.955797914,3.054743126,3.137033781,3.20729756,3.268487467,3.322599532,3.371044021,3.414852999,3.454803702,3.491495545,3.525400183,3.556895173,3.586287277,3.613829002,3.639730587,3.664168877,3.768984411,3.852856766,3.922567075,3.982086486,4.0339352,4.07980988,4.158095381,
       1.943277692,2.33241874,2.550702212,2.701008766,2.814882818,2.906135408,2.982025132,3.04682786,3.103268904,3.153188941,3.19788778,3.23831631,3.275190456,3.309062266,3.340366079,3.369449565,3.396595197,3.42203549,3.445964045,3.468543716,3.565420977,3.642981086,3.70747238,3.762555451,3.810554292,3.853034019,3.925550258,
       1.894667738,2.264183568,2.470505603,2.612324994,2.719681028,2.805675569,2.877178411,2.938230132,2.991403313,3.038434145,3.080547959,3.118640787,3.15338704,3.18530663,3.21480854,3.242220099,3.267807227,3.291788796,3.314347039,3.335635244,3.42699025,3.500152597,3.561003858,3.612990278,3.65830015,3.698407468,3.766889834,
       1.859630577,2.215084263,2.412800263,2.54848954,2.651122432,2.733296603,2.801604904,2.859919969,2.910705143,2.955621735,2.995841609,3.032221342,3.065405444,3.095890644,3.124067609,3.150248955,3.174688619,3.197595582,3.21914383,3.2394797,3.326757857,3.396668445,3.454825139,3.50451722,3.547833424,3.586180783,3.65166868,
       1.833190095,2.178082497,2.369315345,2.500372787,2.599427725,2.678701497,2.74458001,2.800810231,2.849773649,2.893075381,2.931847111,2.966915732,2.998903227,3.028288841,3.055449413,3.080686441,3.104244793,3.126325965,3.147097692,3.16670104,3.250839835,3.318242562,3.374318713,3.42223768,3.464012013,3.500997434,3.564166433,
       1.812533819,2.149207949,2.335384344,2.462820757,2.559072775,2.636070359,2.700039069,2.754628406,2.802156308,2.844184221,2.881812574,2.915845143,2.946886351,2.975401805,3.001757546,3.026246385,3.049106098,3.070532322,3.090687898,3.109709762,3.19135386,3.256760771,3.31117931,3.357684334,3.398228228,3.434126137,3.495442139,
       1.795953749,2.126053349,2.308177485,2.432706578,2.526704373,2.601868673,2.664297214,2.717561755,2.763929501,2.804927014,2.841629731,2.874822935,2.90509699,2.932906576,2.958609078,2.982490335,3.004782433,3.025676303,3.04533085,3.063879691,3.14349243,3.207271955,3.260337423,3.305687278,3.345225205,3.380233463,3.440032501,
       1.782353268,2.107075243,2.285880248,2.408024433,2.50017054,2.573827101,2.63498761,2.687160395,2.732571245,2.772718228,2.808656356,2.841155789,2.870795389,2.89802089,2.923182585,2.946560603,2.968382362,2.988834934,3.008073995,3.026230437,3.104156534,3.166583103,3.218522534,3.262910257,3.301609744,3.335876078,3.394409139,
       1.77099633,2.091238891,2.267276107,2.38742911,2.478027486,2.550422535,2.61052114,2.6617789,2.706387171,2.745820313,2.781116342,2.813032826,2.842139044,2.868873276,2.893579904,2.916534293,2.937959968,2.958040777,2.976929703,2.994755359,3.071258492,3.132542273,3.183529692,3.227103347,3.265092964,3.298730792,3.356190675,
       1.761370646,2.07782487,2.251519229,2.36998505,2.459270766,2.530595002,2.58979154,2.640271473,2.684197076,2.723022685,2.757771953,2.789191802,2.817843412,2.844158755,2.868477213,2.891070116,2.912157695,2.931921068,2.950510934,2.968053977,3.043340478,3.10364613,3.153818002,3.196693781,3.234074476,3.267172894,3.323711127,
       1.753108735,2.066317585,2.238003424,2.355021618,2.443180168,2.513584253,2.572005146,2.621815869,2.66515382,2.703456197,2.737734359,2.768726114,2.796985703,2.822939696,2.846923187,2.869204053,2.889999695,2.909488893,2.927820387,2.945119204,3.019353636,3.07881264,3.128278031,3.170548861,3.207401419,3.240031758,3.29576973,
       1.745940168,2.056337924,2.226282975,2.342045623,2.429225917,2.498830929,2.556577871,2.605806832,2.648633685,2.686480799,2.720348893,2.750967883,2.778886001,2.804525137,2.828216675,2.850225494,2.870766547,2.890016585,2.908122649,2.925208332,2.99852408,3.057243127,3.10609062,3.147832031,3.184222148,3.216442446,3.27147898,
       1.739661534,2.047600939,2.216022886,2.330686332,2.417009701,2.485914387,2.543070382,2.591789012,2.634167343,2.671614788,2.705122765,2.735414293,2.76303235,2.788394736,2.811829586,2.83359916,2.853916268,2.872955885,2.890863567,2.907761649,2.980268345,3.038335222,3.086637764,3.127911997,3.163893843,3.195751979,3.250168644,
       1.734116904,2.039888343,2.206966537,2.320659721,2.406226316,2.474512249,2.531145918,2.579413308,2.621394915,2.658488735,2.691677987,2.721679611,2.749031953,2.774149206,2.797356639,2.818914205,2.839032821,2.857885897,2.875617676,2.892349385,2.964138233,3.021626045,3.069444435,3.1103034,3.145922177,3.177458123,3.231323062,
       1.729184745,2.033030106,2.198914053,2.311744543,2.396637983,2.464373319,2.520542033,2.568407615,2.610035855,2.646814606,2.67971981,2.709463009,2.736578435,2.761477075,2.784481654,2.805850072,2.825791566,2.844478155,2.862052915,2.878636088,2.949783776,3.006754054,3.054139501,3.094626948,3.129920776,3.161168255,3.214538989,
       1.724768941,2.026891827,2.191707448,2.303765912,2.388056723,2.455298982,2.511051188,2.558556728,2.599868246,2.636364536,2.669015031,2.698526447,2.725429338,2.750131824,2.772954358,2.794153001,2.813935489,2.832472594,2.849906351,2.866356119,2.936927742,2.993432758,3.0404288,3.080581949,3.115583273,3.146571002,3.199496538,
       1.720792476,2.021365873,2.185220211,2.29658377,2.380331977,2.447130145,2.502507118,2.549688217,2.590714266,2.626955912,2.659376736,2.688679114,2.715390291,2.739915812,2.762574081,2.783619508,2.803258476,2.821660639,2.838967092,2.8552964,2.925347678,2.981432216,3.028076179,3.067926956,3.102663622,3.133416256,3.185938695,
       1.717192918,2.016365033,2.179349841,2.290084636,2.373341748,2.439737875,2.494775069,2.541662317,2.58242976,2.61844068,2.65065337,2.679766281,2.706303666,2.73066874,2.753178055,2.774084528,2.793593321,2.811873072,2.829064028,2.845284037,2.914863032,2.97056575,3.016889874,3.056465871,3.090961953,3.121500819,3.173656596,
       1.713919127,2.011817899,2.174012413,2.284175593,2.366986133,2.433016588,2.487744673,2.534364544,2.574896639,2.610697549,2.642720763,2.671661165,2.698040291,2.722259239,2.74463288,2.765412772,2.784802964,2.802971177,2.820056884,2.836177281,2.905325735,2.960680231,3.006712553,3.046037777,3.080314232,3.110657901,3.162478756,
       1.71092881,2.00766544,2.169138557,2.278779833,2.361182548,2.42687899,2.481324679,2.527700237,2.568017251,2.603626208,2.635476214,2.664258898,2.690493317,2.714578636,2.73682819,2.757492299,2.776773999,2.794840169,2.811829578,2.827858825,2.896613217,2.951648873,2.997413927,3.036509394,3.070584574,3.100749315,3.15226307,
       1.708186687,2.003858438,2.164670434,2.273833315,2.35586213,2.42125229,2.475438984,2.521590443,2.561710144,2.597142983,2.628834049,2.657471991,2.683573594,2.707536252,2.729671893,2.750229702,2.769411785,2.787384251,2.804285225,2.820230758,2.888623152,2.943365809,2.988885181,3.027769392,3.061659461,3.091659607,3.142890783,
       1.705663101,2.000355525,2.160559436,2.269282218,2.350967003,2.416075305,2.470023623,2.515968796,2.555906845,2.591177528,2.622722238,2.651226883,2.677206161,2.701055835,2.723086541,2.74354642,2.762636723,2.780522849,2.797342331,2.813210718,2.881269444,2.935741948,2.981034732,3.019724057,3.053443323,3.083291566,3.134261882,
       1.703332935,1.997121682,2.156764418,2.265080983,2.346448176,2.41129624,2.46502444,2.510779103,2.550549377,2.585670273,2.617079779,2.645461275,2.671327528,2.695072801,2.717006535,2.737375908,2.756381383,2.774187704,2.790931856,2.806728925,2.874479137,2.928701783,2.973784948,3.012293942,3.045855129,3.075562758,3.126291547,
       1.701174779,1.994127069,2.153250318,2.261190788,2.342263895,2.406870953,2.460395278,2.505973473,2.54558832,2.580570442,2.611854675,2.640122055,2.665883569,2.689532086,2.711375943,2.731661427,2.750588269,2.768320609,2.784994924,2.800725872,2.868190003,2.922180899,2.967069592,3.005411252,3.038825725,3.06840283,3.118907368,
       1.699170269,1.991346096,2.149987075,2.257578346,2.338378362,2.402761595,2.456096559,2.501510832,2.540981291,2.575834487,2.607002325,2.635163672,2.660827856,2.684386457,2.706146785,2.7263543,2.745208054,2.762871626,2.779481022,2.795150501,2.862348641,2.916124009,2.960831807,2.999017785,3.032295739,3.061751368,3.112047161,
       1.697303566,1.988756697,2.146948766,2.254214953,2.334760708,2.398935526,2.452094149,2.49735576,2.53669174,2.571424846,2.602484261,2.63054683,2.65612034,2.679595167,2.701277669,2.721412533,2.740198181,2.75779767,2.774346566,2.789958757,2.856908966,2.910483399,2.955022516,2.993063299,3.026213909,3.055556211,3.105657226,
       1.689612788,1.978092439,2.13443716,2.240365172,2.319864001,2.38318046,2.435612674,2.480245296,2.519027105,2.553265265,2.583877754,2.611533096,2.636732735,2.659862102,2.681223627,2.701058824,2.719563519,2.736898615,2.753197875,2.768573661,2.834500428,2.887245002,2.931087158,2.968527775,3.001151807,3.030025333,3.079320267,
       1.679464552,1.964030754,2.117943462,2.222108899,2.300228135,2.362413048,2.413887355,2.457690312,2.495740973,2.529325985,2.559348578,2.586466324,2.611172313,2.633845465,2.654783035,2.674222359,2.692355841,2.709341547,2.725310864,2.740374143,2.804947389,2.856593612,2.899512639,2.936157785,2.968083432,2.996334853,3.044559169,
       1.675941064,1.959151299,2.112221198,2.215775612,2.293416445,2.35520888,2.406350878,2.449865979,2.487662941,2.521021303,2.550839182,2.577770355,2.602305014,2.624819821,2.645610235,2.664912143,2.682916762,2.699781174,2.715635942,2.730590716,2.794693919,2.845958566,2.888556759,2.924925321,2.956608039,2.984642977,3.03249452,
       1.673069084,1.955175165,2.107558731,2.210615493,2.287866642,2.349339356,2.400210636,2.443491229,2.481081509,2.514255228,2.543906339,2.570685524,2.595080617,2.617466438,2.638136984,2.657326959,2.675226614,2.691992228,2.707753691,2.722620088,2.786340429,2.837294255,2.879631079,2.915774293,2.947259054,2.975117559,3.022665221,
       1.670683215,1.951872784,2.103686632,2.206330254,2.283257865,2.344465116,2.395111616,2.438197495,2.475616172,2.508636591,2.538149248,2.564802257,2.589081492,2.611360242,2.63193129,2.651028359,2.668840894,2.68552451,2.701208538,2.716001589,2.779404208,2.830100108,2.872220038,2.908176239,2.939496705,2.967208764,3.014504154,
       1.668669673,1.949086296,2.100419655,2.202714813,2.279369519,2.340352843,2.390809733,2.43373137,2.471005302,2.503896424,2.533292313,2.559838915,2.58402045,2.606208918,2.626696074,2.645714813,2.663453902,2.680068393,2.695687144,2.710418369,2.773553197,2.824031731,2.865968884,2.901767488,2.932949499,2.960538137,3.007620896,
       1.666947616,1.94670358,2.097626245,2.199623536,2.276044951,2.336836849,2.387131652,2.429912891,2.467063102,2.499843711,2.529139804,2.555595473,2.579693522,2.601804848,2.622220328,2.641172148,2.658848495,2.675403938,2.690966934,2.705645353,2.768551493,2.818844432,2.860625539,2.896289603,2.927353415,2.954836687,3.001737909,
       1.664156802,1.942842866,2.093100423,2.194615291,2.270658849,2.331140698,2.381172981,2.423726843,2.460676702,2.49327837,2.522412894,2.548721361,2.572684281,2.594670763,2.614970259,2.633813806,2.65138865,2.667848579,2.683321394,2.697914413,2.760450801,2.810443767,2.85197272,2.88741941,2.918292266,2.945605321,2.992213265,
       1.661992596,1.939849649,2.089591844,2.190732875,2.266483615,2.326725194,2.376554052,2.418931741,2.455726386,2.48818945,2.517198848,2.543393336,2.567251646,2.589141497,2.609351239,2.628111014,2.645607338,2.661993392,2.677396469,2.691923458,2.754174074,2.803935333,2.845269597,2.8805485,2.911273988,2.938455696,2.984837353,
       1.660265266,1.937461084,2.086792214,2.187635048,2.263152211,2.323202136,2.372868739,2.415105926,2.451776802,2.48412936,2.513039015,2.539142664,2.562917618,2.584730486,2.604868737,2.623561799,2.640995604,2.657322849,2.672670422,2.687144864,2.749168172,2.798745248,2.839924831,2.875070478,2.905678959,2.932756399,2.978958453,
       1.65885466,1.935510767,2.084506381,2.185105815,2.26043232,2.32032581,2.369859987,2.411982513,2.448552397,2.480814801,2.509643096,2.535672662,2.559379649,2.58112976,2.601209741,2.619848439,2.637231308,2.653510648,2.668813014,2.683244669,2.745082969,2.794510243,2.83556409,2.870601461,2.901114902,2.928107671,2.974163912,
       1.657680981,1.933888224,2.082604798,2.183001797,2.258169732,2.31793312,2.367357169,2.40938435,2.445870269,2.478057728,2.506818402,2.532786405,2.556436923,2.578134902,2.598166488,2.616760045,2.634100626,2.650340203,2.665605053,2.680001205,2.74168607,2.790989198,2.831938904,2.866886639,2.897321429,2.924244148,2.970179792,
       1.656689163,1.932517232,2.080998092,2.181224082,2.256258063,2.315911551,2.365242578,2.407189234,2.443604246,2.475728426,2.504432012,2.530348052,2.553950914,2.575604906,2.595595667,2.61415115,2.63145607,2.647662121,2.662895346,2.677261575,2.738817183,2.788015803,2.828877896,2.863750258,2.894118937,2.920982795,2.966817139,
       1.655104721,1.930327319,2.078431788,2.178384706,2.253204788,2.312682791,2.361865301,2.403683407,2.439985243,2.472008442,2.50062095,2.526454105,2.549980971,2.571564837,2.591490529,2.609985341,2.627233453,2.64338611,2.658568981,2.672887578,2.734237574,2.78327013,2.823993129,2.858745918,2.889009785,2.915780369,2.961454278,
       1.653895132,1.928655725,2.076472993,2.176217541,2.250874407,2.310218516,2.35928772,2.401007771,2.437223297,2.469169505,2.497712589,2.523482587,2.546951562,2.568482025,2.58835818,2.606806822,2.624011716,2.640123765,2.655268353,2.669550748,2.730744612,2.779651246,2.820268901,2.854931225,2.885115862,2.911815988,2.95736881,
       1.652536458,1.926778332,2.074273149,2.173783747,2.248257364,2.307451156,2.356393173,2.398003174,2.434121855,2.465981695,2.494446925,2.520146115,2.54355021,2.565020843,2.584841521,2.603238471,2.620394997,2.636461618,2.651563392,2.665805317,2.72682481,2.77559104,2.816091403,2.850653125,2.880749747,2.907371673,2.952790245,
       1.650999327,1.924654646,2.071784849,2.171030905,2.245297315,2.304321153,2.35311939,2.394605015,2.430614272,2.462376561,2.490753888,2.516373165,2.539704068,2.561107237,2.580865387,2.599204106,2.616306172,2.632321665,2.64737528,2.661571701,2.722395417,2.771004364,2.811373603,2.84582306,2.875821619,2.902356539,2.947625992,
       1.649976166,1.923241229,2.070128846,2.169198895,2.24332745,2.302238227,2.350940832,2.392343749,2.428280263,2.459977723,2.488296655,2.513862868,2.53714519,2.558503601,2.578220289,2.596520414,2.613586402,2.629568044,2.644589789,2.658756114,2.719450534,2.767955863,2.808238916,2.842614736,2.87254909,2.899027136,2.944199316)

if(sum(as.numeric(sig)==0.001,as.numeric(sig)==0.01,as.numeric(sig)==0.1,
       as.numeric(sig)==0.05)==0){
  stop("O nivel de significancia deve ser 0.001, 0.01, 0.05 ou 0.01")}

if(as.numeric(sig)==0.001){Mat=matrix(D0.001,ncol=27,byrow = T)}
if(as.numeric(sig)==0.01){Mat=matrix(D0.01,ncol=27,byrow = T)}
if(as.numeric(sig)==0.05){Mat=matrix(D0.05,ncol=27,byrow = T)}
if(as.numeric(sig)==0.1){Mat=matrix(D0.1,ncol=27,byrow = T)}

GLtrat=c(1,	2,	3,	4,	5,	6,	7,	8,	9,	10,	11,	12,	13,	14,	15,	16,	17,	18,
         19,	20,	25,	30,	35,	40,	45,	50,	60)
GLres=c(2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,
        28,29,30,35,45,50,55,60,65,70,80,90,100,110,120,130,150,170,200,250,300)

if(gln>max(GLtrat)){gln=max(GLtrat)}
if(gld>max(GLres)){gld=max(GLres)}
return(Interpolacao(Mat,GLtrat,GLres,gln,gld))
}





